import { Emitter } from '../utils/emitter';
export interface ILeiaRTC {
    /**
     * Creates a local client object for managing a call.
     *
     * This is usually the first step of using the Leia Web SDK.
     * @param config The configurations for the client object, including channel profile and codec. The default codec is `vp8` and default channel profile is `rtc`. See {@link ClientConfig} for details.
     * @category Leia Core
     */
    createClient(config: ClientConfig): ILeiaRTCClient;
    /**
     * Creates a video track from the video captured by a camera.
     *
     * @param config Configurations for the captured video, such as the capture device and the encoder configuration.
     * @category Local Track
     */
    createCameraVideoTrack(config?: CameraVideoTrackInitConfig): Promise<ICameraVideoTrack>;
    /**
     * Creates an audio track from the audio sampled by a microphone.
     *
     * @param config Configurations for the sampled audio, such as the capture device and the encoder configuration. See {@link MicrophoneAudioTrackInitConfig}.
     * @category Local Track
     */
    createMicrophoneAudioTrack(config?: MicrophoneAudioTrackInitConfig): Promise<IMicrophoneAudioTrack>;
    /**
     * Creates a video track for screen sharing.
     *
     * @param config Configurations for the screen-sharing video, such as encoder configuration and capture configuration.
     * @param withAudio Whether to share the audio of the **screen sharing input source** when sharing the screen.
     * - `enable`: Share the audio.
     * - `disable`: (Default) Do not share the audio.
     * - `auto`: Share the audio, dependent on whether the browser supports this function.
     * > Note:
     * > - This function is only supported on Chrome 74 or later on Windows and macOS platforms.
     * > - On Windows, this function allows you to share the audio when sharing the entire screen and sharing Chrome tabs, but not when sharing the application window.
     * On macOS, this function allows you to share the audio only when sharing Chrome tabs.
     * > - For the audio sharing to take effect, the end user must check **Share audio** in the pop-up window when sharing the screen.
     * @returns
     * - If `withAudio` is `enable`, then this method returns a list containing a video track for screen sharing and an audio track. If the end user does not check **Share audio**, the SDK throws an error.
     * - If `withAudio` is `disable`, then this method returns a video track for screen sharing.
     * - If `withAudio` is `auto`, then the SDK attempts to share the audio on browsers supporting this function.
     *   - If the end user checks **Share audio**, then this method returns a list containing a video track for screen sharing and an audio track.
     *   - If the end user does not check **Share audio**, then this method only returns a video track for screen sharing.
     */
    createScreenVideoTrack(config: ScreenVideoTrackInitConfig, withAudio?: 'enable' | 'disable' | 'auto'): Promise<ILocalVideoTrack>;
    /**
     * Creates a customized video track.
     *
     * This method creates a customized video track from a [MediaStreamTrack](https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamTrack) object.
     * @param config Configurations for the customized video track. See {@link CustomVideoTrackInitConfig}.
     * > You can set the sending bitrate for a customized video track by [config]{@link CustomVideoTrackInitConfig}. Other video encoder configurations are not supported.
     * @category Local Track
     */
    createCustomVideoTrack(config: CustomVideoTrackInitConfig): ILocalVideoTrack;
    /**
     * Enumerates the media input and output devices available, such as microphones, cameras, and headsets.
     *
     * If this method call succeeds, the SDK returns a list of media devices in an array of [MediaDeviceInfo](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo) objects.
     *
     * > Note:
     * > - Calling this method turns on the camera and microphone shortly for the device permission request. On browsers including Chrome 81 or later, Firefox, and Safari, the SDK cannot get accurate device information without permission for the media device.
     * > - The [MediaDeviceInfo.deviceId](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo/deviceId) property of a device may change. For example, it is reset when the user clears cookies. Leia does not recommend using the `deviceId` property to implement your business logic.
     *
     * ```javascript
     * getDevices().then(devices => {
     * console.log("first device id", devices[0].deviceId);
     * }).catch(e => {
     * console.log("get devices error!", e);
     * });
     * ```
     * @param skipPermissionCheck Whether to skip the permission check. If you set this parameter as `true`, the SDK does not trigger the request for media device permission. In this case, the retrieved media device information may be inaccurate.
     * - `true`: Skip the permission check.
     * - `false`: (Default) Do not skip the permission check.
     * @category Media Devices
     */
    getDevices(skipPermissionCheck?: boolean): Promise<MediaDeviceInfo[]>;
    /**
     * Enumerates the audio sampling devices available, such as microphones.
     *
     * If this method call succeeds, the SDK returns a list of audio input devices in an array of [MediaDeviceInfo](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo) objects.
     *
     * > Calling this method turns on the microphone shortly for the device permission request. On browsers including Chrome 81 or later, Firefox, and Safari, the SDK cannot get accurate device information without permission for the media device.
     *
     * @param skipPermissionCheck Whether to skip the permission check. If you set this parameter as `true`, the SDK does not trigger the request for media device permission. In this case, the retrieved media device information may be inaccurate.
     * - `true`: Skip the permission check.
     * - `false`: (Default) Do not skip the permission check.
     * @category Media Devices
     */
    getMicrophones(skipPermissionCheck?: boolean): Promise<MediaDeviceInfo[]>;
    /**
     * Enumerates the video capture devices available, such as cameras.
     *
     * If this method call succeeds, the SDK returns a list of video input devices in an array of [MediaDeviceInfo](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo) objects.
     *
     * > Calling this method turns on the camera shortly for the device permission request. On browsers including Chrome 81 or later, Firefox, and Safari, the SDK cannot get accurate device information without permission for the media device.
     *
     * @param skipPermissionCheck Whether to skip the permission check. If you set this parameter as `true`, the SDK does not trigger the request for media device permission. In this case, the retrieved media device information may be inaccurate.
     * - `true`: Skip the permission check.
     * - `false`: (Default) Do not skip the permission check.
     * @category Media Devices
     */
    getCameras(skipPermissionCheck?: boolean): Promise<MediaDeviceInfo[]>;
    /**
     * Set server info such as login ip:port .
     * @param baseURL
     */
    setLoginServer(baseURL: string): void;
    /**
     * Occurs when an audio sampling device is added or removed.
     *
     * ``` javascript
     * LeiaRTC.onMicrophoneChanged = (info) => {
     *   console.log("microphone changed!", info.state, info.device);
     * };
     * ```
     * **Parameters**
     *
     * - **deviceInfo**: The information of the device. See {@link DeviceInfo}.
     * @category Global Callback
     */
    onMicrophoneChanged?: (deviceInfo: DeviceInfo) => void;
    /**
     * Sets the output log level of the SDK.
     *
     * Choose a level to see the logs preceding that level. The log level follows the sequence of NONE, ERROR, WARNING, INFO, and DEBUG.
     *
     * For example, if you set the log level as `LeiaRTC.setLogLevel(1);`, then you can see logs in levels INFO, ERROR, and WARNING.
     * @param level The output log level.
     * - 0: DEBUG. Output all API logs.
     * - 1: INFO. Output logs of the INFO, WARNING and ERROR level.
     * - 2: WARNING. Output logs of the WARNING and ERROR level.
     * - 3: ERROR. Output logs of the ERROR level.
     * - 4: NONE. Do not output any log.
     * @category Logger
     */
    setLogLevel(level: number): void;
}
/**
 * Specifies a constraint for a property, such as the resolution or bitrate for video capture in [[VideoEncoderConfiguration]].
 */
export interface ConstrainLong {
    /**
     * The lower limit of the property.
     */
    min?: number;
    /**
     * The upper limit of the property.
     */
    max?: number;
    /**
     * An ideal value of a property. If the video capture device cannot output this value, it outputs the closest value instead.
     */
    ideal?: number;
    /**
     * A required value of a property. If the video capture device cannot output this value, the video capture fails.
     */
    exact?: number;
}
/**
 * `VideoEncoderConfiguration` is the interface that defines the video encoder configurations.
 *
 * You can customize the video encoder configurations when calling [LeiaRTC.createCameraVideoTrack]{@link ILeiaRTC.createCameraVideoTrack} or [LeiaRTC.createScreenVideoTrack]{@link ILeiaRTC.createScreenVideoTrack}.
 *
 * The SDK provides the preset video encoder configurations. For more information, see [[VideoEncoderConfigurationPreset]].
 *
 * > The actual bitrate may differ slightly from the value you set due to the limitations of the operating system or the web browser. Leia recommends setting the bitrate between 100 Kbps and 5000 Kbps.
 */
export interface VideoEncoderConfiguration {
    /**
     * Width of the video.
     *
     * You can pass a `number`, or a constraint such as `{ max: 1280, min: 720 }`.
     *
     * For more details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    width?: number | ConstrainLong;
    /**
     * Height of the video.
     *
     * You can pass a `number`, or a constraint such as `{ max: 1280, min: 720 }`.
     *
     * For more details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    height?: number | ConstrainLong;
    /**
     * Frame rate of the video (fps).
     *
     * You can pass a `number`, or a constraint such as `{ max: 30, min: 5 }`.
     *
     * For details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    frameRate?: number | ConstrainLong;
    /**
     * The minimum bitrate of the video (Kbps).
     */
    bitrateMin?: number;
    /**
     * The maximum bitrate of the video (Kbps).
     */
    bitrateMax?: number;
}
/**
 * @ignore
 */
export interface SUPPORT_VIDEO_ENCODER_CONFIG_LIST {
    '120p': VideoEncoderConfiguration;
    '120p_1': VideoEncoderConfiguration;
    '120p_3': VideoEncoderConfiguration;
    '180p': VideoEncoderConfiguration;
    '180p_1': VideoEncoderConfiguration;
    '180p_3': VideoEncoderConfiguration;
    '180p_4': VideoEncoderConfiguration;
    '240p': VideoEncoderConfiguration;
    '240p_1': VideoEncoderConfiguration;
    '240p_3': VideoEncoderConfiguration;
    '240p_4': VideoEncoderConfiguration;
    '360p': VideoEncoderConfiguration;
    '360p_1': VideoEncoderConfiguration;
    '360p_3': VideoEncoderConfiguration;
    '360p_4': VideoEncoderConfiguration;
    '360p_6': VideoEncoderConfiguration;
    '360p_7': VideoEncoderConfiguration;
    '360p_8': VideoEncoderConfiguration;
    '360p_9': VideoEncoderConfiguration;
    '360p_10': VideoEncoderConfiguration;
    '360p_11': VideoEncoderConfiguration;
    '480p': VideoEncoderConfiguration;
    '480p_1': VideoEncoderConfiguration;
    '480p_2': VideoEncoderConfiguration;
    '480p_3': VideoEncoderConfiguration;
    '480p_4': VideoEncoderConfiguration;
    '480p_6': VideoEncoderConfiguration;
    '480p_8': VideoEncoderConfiguration;
    '480p_9': VideoEncoderConfiguration;
    '480p_10': VideoEncoderConfiguration;
    '540p': VideoEncoderConfiguration;
    '540p_1': VideoEncoderConfiguration;
    '540p_2': VideoEncoderConfiguration;
    '720p': VideoEncoderConfiguration;
    '720p_1': VideoEncoderConfiguration;
    '720p_2': VideoEncoderConfiguration;
    '720p_3': VideoEncoderConfiguration;
    '720p_5': VideoEncoderConfiguration;
    '720p_6': VideoEncoderConfiguration;
    '1080p': VideoEncoderConfiguration;
    '1080p_1': VideoEncoderConfiguration;
    '1080p_2': VideoEncoderConfiguration;
    '1080p_3': VideoEncoderConfiguration;
    '1080p_5': VideoEncoderConfiguration;
    '1440p': VideoEncoderConfiguration;
    '1440p_1': VideoEncoderConfiguration;
    '1440p_2': VideoEncoderConfiguration;
    '2160p': VideoEncoderConfiguration;
    '2160p_1': VideoEncoderConfiguration;
    '2160p_2': VideoEncoderConfiguration;
}
/**
 *
 * The preset video encoder configurations.
 *
 * You can pass the preset video encoder configurations when calling [LeiaRTC.createCameraVideoTrack]{@link ILeiaRTC.createCameraVideoTrack} or [LeiaRTC.createScreenVideoTrack]{@link ILeiaRTC.createScreenVideoTrack}.
 *
 * The following table lists all the preset video profiles. The SDK uses `"480p_1"` by default.
 *
 * | Video Profile | Resolution (Width×Height) | Frame Rate (fps) | Bitrate (Kbps） | Chrome | Firefox | Safari |
 * | -------- | --------------- | ----------- | ------------ | ------ | ------- | ------ |
 * | 120p     | 160 × 120       | 15          | 130           | ✓      |         |        |
 * | 120p_1   | 160 × 120       | 15          | 130           | ✓      |         |        |
 * | 120p_3   | 120 × 120       | 15          | 130           | ✓      |         |        |
 * | 180p     | 320 × 180       | 15          | 280          | ✓      |         |        |
 * | 180p_1   | 320 × 180       | 15          | 280          | ✓      |         |        |
 * | 180p_3   | 180 × 180       | 15          | 200          | ✓      |         |        |
 * | 180p_4   | 240 × 180       | 15          | 240          | ✓      |         |        |
 * | 240p     | 320 × 240       | 15          | 400          | ✓      |         |        |
 * | 240p_1   | 320 × 240       | 15          | 400          | ✓      |         |        |
 * | 240p_3   | 240 × 240       | 15          | 280          | ✓      |         |        |
 * | 240p_4   | 424 × 240       | 15          | 440          | ✓      |         |        |
 * | 360p     | 640 × 360       | 15          | 800          | ✓      |         |        |
 * | 360p_1   | 640 × 360       | 15          | 800          | ✓      |         |        |
 * | 360p_3   | 360 × 360       | 15          | 520          | ✓      |         |        |
 * | 360p_4   | 640 × 360       | 30          | 1200          | ✓      |         |        |
 * | 360p_6   | 360 × 360       | 30          | 800          | ✓      |         |        |
 * | 360p_7   | 480 × 360       | 15          | 640          | ✓      |         |        |
 * | 360p_8   | 480 × 360       | 30          | 980          | ✓      |         |        |
 * | 360p_9   | 640 × 360       | 15          | 1600          | ✓      |         |        |
 * | 360p_10  | 640 × 360       | 24          | 1600          | ✓      |         |        |
 * | 360p_11  | 640 × 360       | 24          | 2000         | ✓      |         |        |
 * | 480p     | 640 × 480       | 15          | 1000          | ✓      | ✓       | ✓      |
 * | 480p_1   | 640 × 480       | 15          | 1000          | ✓      | ✓       | ✓      |
 * | 480p_2   | 640 × 480       | 30          | 2000         | ✓      | ✓       | ✓      |
 * | 480p_3   | 480 × 480       | 15          | 800          | ✓      | ✓       | ✓      |
 * | 480p_4   | 640 × 480       | 30          | 1500          | ✓      | ✓       | ✓      |
 * | 480p_6   | 480 × 480       | 30          | 1200          | ✓      | ✓       | ✓      |
 * | 480p_8   | 848 × 480       | 15          | 1220          | ✓      | ✓       | ✓      |
 * | 480p_9   | 848 × 480       | 30          | 16200          | ✓      | ✓       | ✓      |
 * | 480p_10  | 640 × 480       | 10          | 800          | ✓      | ✓       | ✓      |
 * | 540p     | 960 × 540      | 15          | 1600         | ✓      | ✓       | ✓      |
 * | 540p_1   | 960 × 540      | 15          | 1600         | ✓      | ✓       | ✓      |
 * | 540p_2   | 960 × 540      | 30          | 2000         | ✓      | ✓       | ✓      |
 * | 720p     | 1280 × 720      | 15          | 2500         | ✓      | ✓       | ✓      |
 * | 720p_1   | 1280 × 720      | 15          | 2500         | ✓      | ✓       | ✓      |
 * | 720p_2   | 1280 × 720      | 30          | 4000         | ✓      | ✓       | ✓      |
 * | 720p_3   | 1280 × 720      | 30          | 2900         | ✓      | ✓       | ✓      |
 * | 720p_5   | 960 × 720       | 15          | 1820          | ✓      | ✓       | ✓      |
 * | 720p_6   | 960 × 720       | 30          | 2760         | ✓      | ✓       | ✓      |
 * | 1080p    | 1920 × 1080     | 15          | 3400         | ✓      |         | ✓      |
 * | 1080p_1  | 1920 × 1080     | 15          | 3400         | ✓      |         | ✓      |
 * | 1080p_2  | 1920 × 1080     | 30          | 3800         | ✓      |         | ✓      |
 * | 1080p_3  | 1920 × 1080     | 30          | 4000         | ✓      |         | ✓      |
 * | 1080p_5  | 1920 × 1080     | 60          | 4200         | ✓      |         | ✓      |
 * | 1440p  | 2560 × 1440     | 30          | 9700         | ✓      |         | ✓      |
 * | 1440p_1  | 2560 × 1440     | 30          | 9700         | ✓      |         | ✓      |
 * | 1440p_2  | 2560 × 1440     | 60          | 14800         | ✓      |         | ✓      |
 * | 2160p  | 3840 × 2160     | 30          | 17820         | ✓      |         | ✓      |
 * | 2160p_1  | 3840 × 2160     | 30          | 17820         | ✓      |         | ✓      |
 * | 2160p_2  | 3840 × 2160     | 60          | 27000         | ✓      |         | ✓      |
 */
export declare type VideoEncoderConfigurationPreset = keyof SUPPORT_VIDEO_ENCODER_CONFIG_LIST;
/**
 * @ignore
 */
export interface SUPPORT_SCREEN_ENCODER_CONFIG_LIST {
    '480p': VideoEncoderConfiguration;
    '480p_1': VideoEncoderConfiguration;
    '480p_2': VideoEncoderConfiguration;
    '480p_3': VideoEncoderConfiguration;
    '720p': VideoEncoderConfiguration;
    '720p_1': VideoEncoderConfiguration;
    '720p_2': VideoEncoderConfiguration;
    '720p_3': VideoEncoderConfiguration;
    '1080p': VideoEncoderConfiguration;
    '1080p_1': VideoEncoderConfiguration;
    '1080p_2': VideoEncoderConfiguration;
    '1080p_3': VideoEncoderConfiguration;
}
/**
 * The preset video encoder configurations for screen sharing.
 *
 * You can pass the preset video encoder configurations when calling [LeiaRTC.createScreenVideoTrack]{@link ILeiaRTC.createScreenVideoTrack}.
 *
 * The following table lists all the preset video profiles for screen sharing.
 *
 * | Video Profile | Resolution (Width×Height) | Frame Rate (fps) |
 * | -------- | --------------- | ----------- |
 * | "480p"     | 640 × 480       | 15           |
 * | "480p_1"   | 640 × 480       | 5           |
 * | "480p_2"   | 640 × 480       | 30          |
 * | "480p_3"   | 640 × 480       | 15          |
 * | "720p"     | 1280 × 720      | 15           |
 * | "720p_1"   | 1280 × 720      | 5           |
 * | "720p_2"   | 1280 × 720      | 30          |
 * | "720p_3"   | 1280 × 720      | 15          |
 * | "1080p"    | 1920 × 1080     | 15           |
 * | "1080p_1"  | 1920 × 1080     | 5           |
 * | "1080p_2"  | 1920 × 1080     | 30          |
 * | "1080p_3"  | 1920 × 1080     | 15          |
 */
export declare type ScreenEncoderConfigurationPreset = keyof SUPPORT_SCREEN_ENCODER_CONFIG_LIST;
/**
 * Configurations for the video track from the video captured by a camera. Set these configurations when calling [LeiaRTC.createCameraVideoTrack]{@link ILeiaRTC.createCameraVideoTrack}.
 */
export interface CameraVideoTrackInitConfig {
    /**
     * The video encoder configurations.
     *
     * You can set the video encoder configurations in either of the following ways:
     * - Pass the preset video encoder configurations by using [[VideoEncoderConfigurationPreset]].
     * - Pass your customized video encoder configurations by using [[VideoEncoderConfiguration]].
     */
    encoderConfig?: VideoEncoderConfiguration | VideoEncoderConfigurationPreset;
    /**
     * Whether to user the front camera or the rear camera.
     *
     * You can use this parameter to choose between the front camera and the rear camera on a mobile device:
     * - `"user"`: The front camera.
     * - `"environment"`: The rear camera.
     */
    facingMode?: 'user' | 'environment';
    /**
     * Specifies the camera ID.
     *
     * You can get a list of the available cameras by calling [LeiaRTC.getCameras]{@link ILeiaRTC.getCameras}.
     */
    cameraId?: string;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Transmission optimization mode. Whether to prioritize video quality or smoothness:
     * - `"detail"`: Prioritizes video quality.
     *   - The SDK ensures high-quality images by automatically calculating a minimum bitrate based on the capturing resolution and frame rate. No matter how poor the network condition is, the sending bitrate will never be lower than the minimum value.
     *   - In most cases, the SDK does not reduce the sending resolution, but may reduce the frame rate.
     * -  `"motion"`: Prioritizes video smoothness.
     *   - In poor network conditions, the SDK reduces the sending bitrate to minimize video freezes.
     *   - In most cases, the SDK does not reduce the frame rate, but may reduce the sending resolution.
     * - Empty: Uses the default transmission optimization mode. The SDK may reduce the frame rate or the sending resolution in poor network conditions.
     *
     * > Note: This method is only supported on Chrome.
     */
    optimizationMode?: 'motion' | 'detail';
}
/**
 * Configurations for the custom video track. Set these configurations when calling [LeiaRTC.createCustomVideoTrack]{@link ILeiaRTC.createCustomVideoTrack}.
 */
export interface CustomVideoTrackInitConfig {
    /**
     * Your [MediaStreamTrack](https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamTrack) object.
     */
    mediaStreamTrack: MediaStreamTrack;
    /**
     * The minimum bitrate of sending the video track (Kbps).
     */
    bitrateMin?: number;
    /**
     * The maximum bitrate of sending the video track (Kbps).
     */
    bitrateMax?: number;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Transmission optimization mode. Whether to prioritize video quality or smoothness:
     * - `"detail"`: Prioritizes video quality.
     *   - The SDK ensures high-quality images by automatically calculating a minimum bitrate based on the capturing resolution and frame rate. No matter how poor the network condition is, the sending bitrate will never be lower than the minimum value.
     *   - In most cases, the SDK does not reduce the sending resolution, but may reduce the frame rate.
     * -  `"motion"`: Prioritizes video smoothness.
     *   - In poor network conditions, the SDK reduces the sending bitrate to minimize video freezes.
     *   - In most cases, the SDK does not reduce the frame rate, but may reduce the sending resolution.
     * - Empty: Uses the default transmission optimization mode. The SDK may reduce the frame rate or the sending resolution in poor network conditions.
     *
     * > Note: This method is only supported on Chrome.
     */
    optimizationMode?: 'motion' | 'detail';
}
export interface ScreenVideoTrackInitConfig {
    /**
     * The video encoder configurations for screen sharing.
     *
     * You can set the video encoder configurations in either of the following ways:
     * - Pass the preset video encoder configurations by using [[ScreenEncoderConfigurationPreset]].
     * - Pass your customized video encoder configurations by using [[VideoEncoderConfiguration]].
     */
    encoderConfig?: VideoEncoderConfiguration | ScreenEncoderConfigurationPreset;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Transmission optimization mode. Whether to prioritize video quality or smoothness:
     * - `"detail"`: (Default) Prioritizes video quality.
     *   - The SDK ensures high-quality images by automatically calculating a minimum bitrate based on the capturing resolution and frame rate. No matter how poor the network condition is, the sending bitrate will never be lower than the minimum value.
     *   - In most cases, the SDK does not reduce the sending resolution, but may reduce the frame rate.
     * -  `"motion"`: Prioritizes video smoothness.
     *   - In poor network conditions, the SDK reduces the sending bitrate to minimize video freezes.
     *   - In most cases, the SDK does not reduce the frame rate, but may reduce the sending resolution.
     *
     * > Note: This method is only supported on Chrome.
     */
    optimizationMode?: 'motion' | 'detail';
}
/**
 *
 * `AudioEncoderConfiguration` is the interface that defines the audio encoder configurations.
 *
 * You can customize the audio encoder configurations when calling [LeiaRTC.createCustomAudioTrack]{@link ILeiaRTC.createCustomAudioTrack}, [LeiaRTC.createMicrophoneAudioTrack]{@link ILeiaRTC.createMicrophoneAudioTrack} or [LeiaRTC.createBufferSourceAudioTrack]{@link ILeiaRTC.createBufferSourceAudioTrack}.
 */
export interface AudioEncoderConfiguration {
    /**
     * Sample rate of the audio (Hz).
     */
    sampleRate?: number;
    /**
     * Sample size of the audio.
     */
    sampleSize?: number;
    /**
     * Whether to enable stereo.
     */
    stereo?: boolean;
    /**
     * Bitrate of the audio (Kbps).
     */
    bitrate?: number;
}
/**
 * @ignore
 */
export interface AUDIO_ENCODER_CONFIG_SETTINGS {
    speech_low_quality: AudioEncoderConfiguration;
    speech_standard: AudioEncoderConfiguration;
    music_standard: AudioEncoderConfiguration;
    standard_stereo: AudioEncoderConfiguration;
    high_quality: AudioEncoderConfiguration;
    high_quality_stereo: AudioEncoderConfiguration;
}
/**
 * The preset audio encoder configurations.
 *
 * You can pass the preset video encoder configurations when calling the following methods:
 * - [LeiaRTC.createCustomAudioTrack]{@link ILeiaRTC.createCustomAudioTrack}
 * - [LeiaRTC.createMicrophoneAudioTrack]{@link ILeiaRTC.createMicrophoneAudioTrack}
 * - [LeiaRTC.createBufferSourceAudioTrack]{@link ILeiaRTC.createBufferSourceAudioTrack}
 *
 * The following table lists all the preset audio profiles. The SDK uses `"music_standard"` by default.
 *
 * | Audio Profile | Configurations |
 * | -------- | --------------- |
 * |`"speech_low_quality"`|Sample rate 16 kHz, mono, encoding rate 24 Kbps|
 * |`"speech_standard"`|Sample rate 32 kHz, mono, encoding rate 24 Kbps|
 * |`"music_standard"`|Sample rate 48 kHz, mono, encoding rate 40 Kbps|
 * |`"standard_stereo"`|Sample rate 48 kHz, stereo, encoding rate 64 Kbps|
 * |`"high_quality"`|Sample rate 48 kHz, mono, encoding rate 128 Kbps|
 * |`"high_quality_stereo"`|Sample rate 48 kHz, stereo, encoding rate 192 Kbps| Kbps.
 * @public
 */
export declare type AudioEncoderConfigurationPreset = keyof AUDIO_ENCODER_CONFIG_SETTINGS;
/**
 * Configurations for the audio track from the audio captured by a microphone. Set these configurations when calling [LeiaRTC.createMicrophoneAudioTrack]{@link ILeiaRTC.createMicrophoneAudioTrack}.
 */
export interface MicrophoneAudioTrackInitConfig {
    /**
     * The audio encoder configurations.
     *
     * You can set the audio encoder configurations in either of the following ways:
     * - Pass the preset audio encoder configurations by using [[AudioEncoderConfigurationPreset]].
     * - Pass your customized audio encoder configurations by using [[AudioEncoderConfiguration]].
     *
     * > Firefox does not support setting the audio encoding rate.
     */
    encoderConfig?: AudioEncoderConfiguration | AudioEncoderConfigurationPreset;
    /**
     * Whether to enable acoustic echo cancellation:
     * - `true`: Enable acoustic echo cancellation.
     * - `false`: Do not enable acoustic echo cancellation.
     */
    AEC?: boolean;
    /**
     * Whether to enable audio gain control:
     * - `true`: Enable audio gain control.
     * - `false`: Do not enable audio gain control.
     */
    AGC?: boolean;
    /**
     * Whether to enable automatic noise suppression:
     * - `true`: Enable automatic noise suppression.
     * - `false`: Do not automatic noise suppression.
     */
    ANS?: boolean;
    /**
     * Specifies the microphone ID.
     *
     * You can get a list of the available microphones by calling [LeiaRTC.getMicrophones]{@link ILeiaRTC.getMicrophones}.
     */
    microphoneId?: string;
}
/**
 * The state of the media input device.
 * - `"ACTIVE"`: The device is plugged in.
 * - `"INACTIVE"`: The device is unplugged.
 */
export declare type DeviceState = 'ACTIVE' | 'INACTIVE';
/**
 * Information of the media input device.
 *
 * - You can get the audio sampling device information through [onMicrophoneChanged]{@link onMicrophoneChanged}.
 */
export interface DeviceInfo {
    /**
     * The latest time when the state of the media input device was updated.
     *
     * A Unix timestamp in milliseconds.
     */
    updateAt: number;
    /**
     * The time when the SDK first detects the media input device.
     *
     * A Unix timestamp in milliseconds.
     */
    initAt: number;
    /**
     * The state of the capture device.
     */
    state: DeviceState;
    /**
     * Device information of the media input device. See [MediaDeviceInfo](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo) for details.
     */
    device: MediaDeviceInfo;
}
/**
 * 用于控制客户端行为的接口。
 */
export interface ClientConfig {
    /**
     * 频道场景。
     */
    mode: SDK_MODE;
    /**
     * 浏览器使用的编码格式
     */
    codec: SDK_CODEC;
}
export declare type SDK_MODE = 'live' | 'rtc';
/**
 * The codec that the Web browser uses for encoding.
 * - `"vp8"`: Use VP8 for encoding.
 * - `"h264"`: Use H.264 for encoding.
 * - `"vp9"`: Reserved, unavailable now.
 * - `"av1"`: Reserved, unavailable now.
 *
 * > Safari 12.1 or earlier does not support the VP8 codec.
 */
export declare type SDK_CODEC = 'h264' | 'vp8' | 'vp9' | 'av1';
export declare type UID = number;
/**
 * Playback configurations for a video track. Set the playback configurations for a video track when calling [ILocalVideoTrack.play]{@link ILocalVideoTrack.play}.
 */
export interface VideoPlayerConfig {
    /**
     * Sets whether to enable mirror mode:
     * - `true`: Enable mirror mode.
     * - `false`: Disable mirror mode.
     *
     * > Notes:
     * > - The SDK enables mirror mode for the local video track by default.
     * > - The SDK disables mirror mode for the remote video track by default.
     */
    mirror?: boolean;
    /**
     * Sets video display mode:
     * - `"cover"`: The image files the height and width of the box, while maintaining its aspect ratio but often cropping the image in the process. For more information, see the `cover` option of `object-fit` in CSS.
     * - `"contain"`: The size of the image increases or decreases to fill the box while preserving its aspect-ratio. Areas that are not filled due to the disparity in the aspect ratio are filled with black. For more information, see the `contain` option of `object-fit` in CSS.
     * - `"fill"`: The image stretches to fit the box, regardless of its aspect-ratio. For more information, see the `fill` option of `object-fit` in CSS.
     *
     * > Notes:
     * > - When playing the local camera video track, the SDK uses cover mode by default; when playing the local video track of screen sharing, the SDK uses contain mode by default.
     * > - When playing the remote video track, the SDK uses cover mode by default.
     */
    fit?: 'cover' | 'contain' | 'fill';
}
export interface ITrack extends Emitter {
    /**
     * The type of a media track:
     * - `"audio"`: Audio track.
     * - `"video"`: Video track.
     */
    trackMediaType: 'audio' | 'video';
    /**
     * Whether a media track is playing on the webpage:
     * - `true`: The media track is playing on the webpage.
     * - `false`: The media track is not playing on the webpage.
     */
    isPlaying: boolean;
    /**
     * Gets the ID of a media track, a unique identifier generated by the SDK.
     *
     * @return The media track ID.
     */
    getTrackId(): string;
    /**
     * Gets an [MediaStreamTrack](https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamTrack) object.
     *
     * @return An [MediaStreamTrack](https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamTrack) object.
     */
    getMediaStreamTrack(): MediaStreamTrack;
    /**
     * Plays a media track on the webpage.
     *
     * @param element Specifies a DOM element. The SDK will create a `<video>` element under the specified DOM element to play the video track. You can specify a DOM element in either of following ways:
     * - `string`: Specify the ID of the DOM element.
     * - `HTMLElement`: Pass a DOM object.
     */
    play(element?: string | HTMLElement): void;
    /**
     * Stops playing the media track.
     */
    stop(): void;
}
/**
 * `RemoteTrack` is the basic interface for remote tracks, providing public methods for [RemoteAudioTrack]{@link IRemoteAudioTrack} and [RemoteVideoTrack]{@link IRemoteVideoTrack}.
 */
export interface IRemoteTrack extends ITrack {
    /**
     * Gets the `uid` of the remote user who publishes the remote track.
     *
     * @return The `uid` of the remote user.
     */
    getUserId(): UID;
}
/**
 * `RemoteAudioTrack` is the basic interface for the remote audio track.
 *
 * You can get create a remote audio track by the [LeiaRTCRemoteUser.audioTrack]{@link ILeiaRTCRemoteUser.audioTrack} object after calling [subscribe]{@link ILeiaRTCClient.subscribe}.
 */
export interface IRemoteAudioTrack extends IRemoteTrack {
    /**
     * Plays a remote audio track.
     *
     * > When playing the audio track, you do not need to pass any DOM element.
     */
    play(): void;
    /**
     * Sets the volume of a remote audio track.
     *
     * @param volume The volume. The value ranges from 0 (mute) to 100 (maximum). A value of 100 is the current volume.
     */
    setVolume(volume: number): void;
    /**
     * Gets the audio level of a remote audio track.
     *
     * @returns The audio level. The value range is [0,1]. 1 is the highest audio level.
     */
    getVolumeLevel(): number;
}
/**
 * `RemoteVideoTrack` is the basic interface for the remote video track.
 *
 * You can get create a remote video track by the [LeiaRTCRemoteUser.videoTrack]{@link ILeiaRTCRemoteUser.videoTrack} object after calling [subscribe]{@link ILeiaRTCClient.subscribe}.
 */
export interface IRemoteVideoTrack extends IRemoteTrack {
    /**
     * Plays a remote video track on the web page.
     *
     * @param element Specifies a DOM element. The SDK will create a `<video>` element under the specified DOM element to play the video track. You can specify a DOM element in either of following ways:
     * - `string`: Specify the ID of the DOM element.
     * - `HTMLElement`: Pass a DOM object.
     * @param config Sets the playback configurations, such as display mode and mirror mode. See [[VideoPlayerConfig]]. By default, the SDK enables mirror mode for a local video track.
     */
    play(element: string | HTMLElement, config?: VideoPlayerConfig): void;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.1.0*
     *
     * Gets the data of the video frame being rendered.
     *
     * > You should call this method after calling [[play]]. Otherwise, the method call returns null.
     *
     * @returns An `ImageData` object that stores RGBA data. `ImageData` is a web API supported by the browser. For details, see [ImageData](https://developer.mozilla.org/en-US/docs/Web/API/ImageData).
     */
    getCurrentFrameData(): ImageData;
}
/**
 * `LocalTrack` is the basic interface for local tracks, providing public methods for [LocalAudioTrack]{@link ILocalAudioTrack} and [LocalVideoTrack]{@link ILocalVideoTrack}.
 */
export interface ILocalTrack extends ITrack {
    on<T extends keyof LocalTrackEvent>(e: T, cb: LocalTrackEvent[T]): void;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Enables/Disables the track.
     *
     * After a track is disabled, the SDK stops playing and publishing the track.
     *
     * > - Disabling a track does not trigger the [LocalTrack.on("track-ended")]{@link event_track_ended} event.
     * > - If a track is published, disabling this track triggers the [user-unpublished]{@link ILeiaRTCClient.event_user_unpublished} event on the remote client, and re-enabling this track triggers the [user-published]{@link ILeiaRTCClient.event_user_published} event.
     * > - Do not call `setEnabled` and `setMuted` together.
     *
     * @param enabled Whether to enable the track:
     * - `true`: Enable the track.
     * - `false`: Disable the track.
     */
    setEnabled(enabled: boolean): Promise<void>;
    /**
     * Gets the label of a local track.
     *
     * @return The label that the SDK returns may include:
     * - The [MediaDeviceInfo.label](https://developer.mozilla.org/en-US/docs/Web/API/MediaDeviceInfo/label) property, if the track is created by calling `createMicrophoneAudioTrack` or `createCameraVideoTrack`.
     * - The `sourceId` property, if the track is created by calling `createScreenVideoTrack`.
     * - The [MediaStreamTrack.label](https://developer.mozilla.org/en-US/docs/Web/API/MediaStreamTrack/label) property, if the track is created by calling `createCustomAudioTrack` or `createCustomVideoTrack`.
     */
    getTrackLabel(): string;
    /**
     * Sends or stops sending the media data of the track.
     *
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.6.0*
     *
     * If the track is published, a successful call of `setMuted(true)` triggers the [user-unpublished]{@link ILeiaRTCClient.event_user_unpublished} event on the remote client, and a successful call of `setMuted(false)` triggers the [user-published]{@link ILeiaRTCClient.event_user_published} event.
     *
     * > - Calling `setMuted(true)` does not stop capturing audio or video and takes shorter time to take effect than [[setEnabled]]. For details, see [What are the differences between setEnabled and setMuted?](https://docs.agora.io/en/Interactive%20Broadcast/faq/differences_between_setenabled_and_setmuted).
     * > - Do not call `setEnabled` and `setMuted` together.
     *
     * @param muted Whether to stop sending the media data of the track:
     * - `true`: Stop sending the media data of the track.
     * - `false`: Resume sending the media data of the track.
     */
    setMuted(muted: boolean): Promise<void>;
    /**
     * Closes a local track and releases the audio and video resources that it occupies.
     *
     * Once you close a local track, you can no longer reuse it.
     */
    close(): void;
    muted: boolean;
    enabled: boolean;
}
/**
 * `LocalAudioTrack` is the basic interface for local audio tracks, providing main methods of local audio tracks.
 *
 * You can create a local audio track by calling [LeiaRTC.createCustomAudioTrack]{@link ILeiaRTC.createCustomAudioTrack}.
 *
 * The following interfaces are inherited from `LocalAudioTrack`:
 * - [MicrophoneAudioTrack]{@link IMicrophoneAudioTrack}, the interface for the audio sampled by a local microphone, which adds several microphone-related functions.
 * - [BufferSourceAudioTrack]{@link IBufferSourceAudioTrack}, the interface for the audio from a local audio file, which adds several audio-file-related functions.
 */
export interface ILocalAudioTrack extends ILocalTrack {
    /**
     * Sets the volume of a local audio track.
     *
     * @param volume The volume. The value ranges from 0 (mute) to 1000 (maximum). A value of 100 is the original volume。 The volume change may not be obvious to human ear. If local track has been published, setting volume will affect the volume heard by remote users.
     */
    setVolume(volume: number): void;
    /**
     * Gets the audio level of a local audio track.
     *
     * @returns The audio level. The value range is [0,1]. 1 is the highest audio level.
     */
    getVolumeLevel(): number;
    /**
     * Plays a local audio track.
     *
     * > When playing a audio track, you do not need to pass any DOM element.
     */
    play(): void;
}
/**
 * `LocalVideoTrack` is the basic interface for local video tracks, providing the main methods for local video tracks.
 *
 * You can get create a local video track by calling [LeiaRTC.createCustomVideoTrack]{@link ILeiaRTC.createCustomVideoTrack} or [LeiaRTC.createScreenVideoTrack]{@link ILeiaRTC.createScreenVideoTrack} method.
 *
 * Inherited from `LocalVideoTrack`, [CameraVideoTrack]{@link ICameraVideoTrack} is an interface for the video captured by a local camera and adds several camera-related functions.
 */
export interface ILocalVideoTrack extends ILocalTrack {
    /**
     * Plays a local video track on the web page.
     *
     * @param element Specifies a DOM element. The SDK will create a `<video>` element under the specified DOM element to play the video track. You can specify a DOM element in either of the following ways:
     * - `string`: Specify the ID of the DOM element.
     * - `HTMLElement`: Pass a DOM object.
     * @param config Sets the playback configurations, such as display mode and mirror mode. See [[VideoPlayerConfig]]. By default, the SDK enables mirror mode for a local video track.
     */
    play(element: string | HTMLElement, config?: VideoPlayerConfig): void;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.1.0*
     *
     * Gets the data of the video frame being rendered.
     *
     * > You should call this method after calling [[play]]. Otherwise, the method call returns null.
     *
     * @returns An `ImageData` object that stores RGBA data. `ImageData` is a web API supported by the browser. For details, see [ImageData](https://developer.mozilla.org/en-US/docs/Web/API/ImageData).
     */
    getCurrentFrameData(): ImageData;
}
/**
 * Inherited from [LocalAudioTrack]{@link ILocalAudioTrack}, `MicrophoneAudioTrack` is an interface for the audio sampled by a local microphone and adds several functions such as switching devices.
 *
 * You can create a local microphone audio track by calling [LeiaRTC.createMicrophoneAudioTrack]{@link ILeiaRTC.createMicrophoneAudioTrack}.
 */
export interface IMicrophoneAudioTrack extends ILocalAudioTrack {
    /**
     * Sets the device for sampling audio.
     *
     * > You can call the method either before or after publishing an audio track.
     *
     * @param deviceId The ID of the specified device. You can get the `deviceId` by calling [LeiaRTC.getMicrophones]{@link ILeiaRTC.getMicrophones}.
     */
    setDevice(deviceId: string): Promise<void>;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Enables/Disables the track.
     *
     * After a track is disabled, the SDK stops playing and publishing the track.
     *
     * > - Disabling a track does not trigger the [LocalTrack.on("track-ended")]{@link event_track_ended} event.
     * > - If a track is published, disabling this track triggers the [user-unpublished]{@link ILeiaRTCClient.event_user_unpublished} event on the remote client, and re-enabling this track triggers the [user-published]{@link ILeiaRTCClient.event_user_published} event.
     * > - Do not call `setEnabled` and `setMuted` together.
     *
     * @param enabled Whether to enable the track:
     * - `true`: Enable the track.
     * - `false`: Disable the track.
     */
    setEnabled(enabled: boolean): Promise<void>;
}
/**
 *
 * Inherited from [LocalVideoTrack]{@link ILocalVideoTrack}, `CameraVideoTrack` is an interface for the video captured by a local camera and adds functions such as switching devices and adjusting video encoder configurations.
 *
 * You can create a local camera video track by calling [LeiaRTC.createCameraVideoTrack]{@link ILeiaRTC.createCameraVideoTrack}.
 */
export interface ICameraVideoTrack extends ILocalVideoTrack {
    /**
     * Sets the device for capturing video.
     *
     * > You can call this method either before or after publishing the video track.
     *
     * @param deviceId The ID of the specified device. You can get the `deviceId` by calling [LeiaRTC.getCameras]{@link ILeiaRTC.getCameras}.
     */
    setDevice(deviceId: string): Promise<void>;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * Enables/Disables the track.
     *
     * After a track is disabled, the SDK stops playing and publishing the track.
     *
     * > - Disabling a track does not trigger the [LocalTrack.on("track-ended")]{@link event_track_ended} event.
     * > - If a track is published, disabling this track triggers the [user-unpublished]{@link ILeiaRTCClient.event_user_unpublished} event on the remote client, and re-enabling this track triggers the [user-published]{@link ILeiaRTCClient.event_user_published} event.
     * > - Do not call `setEnabled` and `setMuted` together.
     *
     * @param enabled Whether to enable the track:
     * - `true`: Enable the track.
     * - `false`: Disable the track.
     */
    setEnabled(enabled: boolean): Promise<void>;
    /**
     * Sets the video encoder configurations, such as resolution, frame rate, and bitrate.
     *
     * > Note: This method is not supported on mobile devices.
     *
     * @param config The video encoder configurations. You can pass either [[VideoEncoderConfigurationPreset]] or a customized [[VideoEncoderConfiguration]] object.
     */
    setEncoderConfiguration(config: VideoEncoderConfiguration | VideoEncoderConfigurationPreset): Promise<void>;
}
export interface ILeiaRTCRemoteUser {
    /**
     * The ID of the remote user.
     */
    uid: UID;
    /**
     * The subscribed audio track.
     */
    audioTrack?: IRemoteAudioTrack;
    /**
     * The subscribed video track.
     */
    videoTrack?: IRemoteVideoTrack;
    /**
     * Whether the remote user is sending an audio track.
     * - `true`: The remote user is sending an audio track.
     * - `false`: The remote user is not sending an audio track.
     */
    hasAudio: boolean;
    /**
     * Whether the remote user is sending a video track.
     * - `true`: The remote user is sending an audio track.
     * - `false`: The remote user is not sending an audio track.
     */
    hasVideo: boolean;
}
/**
 * Connection state between the SDK and Leia's edge server.
 *
 * You can get the connection state through [connectionState]{@link ILeiaRTCClient.connectionState}.
 *
 * The connection between the SDK and the edge server has the following states:
 * - `"DISCONNECTED"`: The SDK is disconnected from the server.
 *  - This is the initial state until you call [join]{@link ILeiaRTCClient.join}.
 *  - The SDK also enters this state after you call [leave]{@link ILeiaRTCClient.leave}, when the user is banned, or when the connection fails.
 * - `"CONNECTING"`: The SDK is connecting to the server. The SDK enters this state when you call [join]{@link ILeiaRTCClient.join}.
 * - `"CONNECTED"`: The SDK is connected to the server and joins a channel. The user can now publish streams or subscribe to streams in the channel.
 * - `"RECONNECTING"`: The SDK is reconnecting to the server. If the connection is lost because the network is down or switched, the SDK enters this state.
 * - `"DISCONNECTING"`: The SDK is disconnecting from the server. The SDK enters this state when you call [leave]{@link ILeiaRTCClient.leave}.
 */
export declare type ConnectionState = 'DISCONNECTED' | 'CONNECTING' | 'RECONNECTING' | 'CONNECTED' | 'DISCONNECTING';
/**
 * The video type of the remote stream. Set the video type of the remote stream when calling [setRemoteVideoStreamType]{@link ILeiaRTCClient.setRemoteVideoStreamType}.
 */
export declare enum RemoteStreamType {
    /**
     * 1: High-quality video stream (high-bitrate, high-resolution).
     */
    HIGH_STREAM = "1",
    /**
     * 2: Low-quality video stream (low-bitrate, low-resolution).
     */
    LOW_STREAM = "2",
    AUTO_STREAM = "auto"
}
/**
 * The video profile of the low-quality video stream. Set the video profile of the low-quality video stream when calling [setLowStreamParameter]{@link ILeiaRTCClient.setLowStreamParameter}.
 */
export interface LowStreamParameter {
    /**
     * Width of the video.
     *
     * You can pass a `number`, or a constraint such as `{ max: 1280, min: 720 }`.
     *
     * For more details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    width: number;
    /**
     * Height of the video.
     *
     * You can pass a `number`, or a constraint such as `{ max: 1280, min: 720 }`.
     *
     * For more details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    height: number;
    /**
     * Frame rate of the video (fps).
     *
     * You can pass a `number`, or a constraint such as `{ max: 30, min: 5 }`.
     *
     * For details about the constraint, see [ConstrainLong]{@link ConstrainLong}.
     */
    framerate?: number;
    /**
     * Bitrate of the video (Kbps).
     */
    bitrate?: number;
}
export interface ILeiaRTCClient extends Emitter {
    /**
     * Connection state between the SDK and the Leia server.
     */
    readonly connectionState: ConnectionState;
    /**
     * The ID of the local user.
     *
     * The value is `undefined` if the local user has not joined a channel.
     */
    readonly uid?: number;
    /**
     * The current channel name.
     *
     * The value is `undefined` if the local user has not joined a channel.
     */
    readonly channelName?: string;
    /**
     * **Since**
     * <br>&emsp;&emsp;&emsp;*4.0.0*
     *
     * The list of the local tracks that the local user is publishing.
     *
     * - After a success method call of [[publish]], the published track object is added to this list automatically.
     * - After a success method call of [[unpublish]], the unpublished track object is removed from this list automatically.
     */
    readonly localTracks: ILocalTrack[];
    /**
     * A list of the remote users in the channel, each of which includes the user ID and the corresponding track information.
     *
     * The list is empty if the local user has not joined a channel.
     */
    readonly remoteUsers: ILeiaRTCRemoteUser[];
    on<T extends keyof ClientEvent>(e: T, cb: ClientEvent[T]): void;
    join(appId: string, channel: string, appKey: string | null, uid?: UID | null): Promise<number>;
    leave(): Promise<void>;
    publish(tracks: ILocalTrack | ILocalTrack[]): Promise<void>;
    unpublish(tracks?: ILocalTrack | ILocalTrack[]): Promise<void>;
    subscribe(user: ILeiaRTCRemoteUser, mediaType: 'video' | 'audio', options?: SubscribeOptions): Promise<IRemoteTrack>;
    unsubscribe(user: ILeiaRTCRemoteUser, mediaType?: 'video' | 'audio'): Promise<void>;
    /**
     * Enables the volume indicator.
     *
     * This method enables the SDK to regularly report the remote users who are speaking and their volumes.
     *
     * After the volume indicator is enabled, the SDK triggers the [LeiaRTCClient.on("volume-indicator")]{@link event_volume_indicator} callback to report the volumes every two seconds, regardless of whether there are active speakers in the channel.
     *
     * > If the local user leaves the channel and rejoins the channel, you need to call `enableAudioVolumeIndicator` again.
     *
     * ```javascript
     * client.enableAudioVolumeIndicator();
     * client.on("volume-indicator", volumes => {
     *   volumes.forEach((volume, index) => {
     *     console.log(`${index} UID ${volume.uid} Level ${volume.level}`);
     *   });
     * })
     * ```
     */
    enableAudioVolumeIndicator(): void;
    /**
     * Sets the video profile of the low-quality video stream.
     *
     * If you have enabled the dual-stream mode by calling {@link enableDualStream}, use this method to set the low-quality video stream profile.
     *
     * If you do not set the low-quality video stream profile, the SDK assigns the default values based on your stream video profile.
     *
     * > Note:
     * > - Firefox: Frame rate settings do not take effect. The browser sets the frame rate as 30 fps.
     * > - iOS Safari: The browser does not support setting `LowStreamParameter.bitrate`. The resolution of the low-quality stream must be proportional to the resolution of the high-quality stream.
     * > - Due to limitations of some devices and browsers, the resolution you set may get adjusted by the browser. In this case, billings are calculated based on the actual resolution.
     * > - Call this method before calling {@link publish}.
     * @param streamParameter The video profile of the low-quality video stream.
     * @category Dual Stream
     */
    setLowStreamParameter(streamParameter: LowStreamParameter): void;
    /**
     * Enables dual-stream mode.
     *
     * Enables dual-stream mode for the local stream. Dual streams are a hybrid of a high-quality video stream and a low-quality video stream:
     * - High-quality video stream: High bitrate, high resolution.
     * - Low-quality video stream: Low bitrate, low resolution. The default video profile of the low-quality stream is: A resolution (width × height) of 160 × 120 px, a bitrate of 50 Kbps, and a frame rate of 15 fps. Call {@link setLowStreamParameter} to customize the video profile of the low-quality stream.
     *
     * > Note:
     * > - `enableDualStream` does not apply to the following scenarios:
     * >   - The video tracks created by calling `createCustomVideoTrack`.
     * >   - Audio-only mode.
     * >   - Screen sharing.
     * > - Leia does not suggest enabling dual-stream mode on mobile devices.
     * > - On Android Chrome, the Web SDK cannot send high-quality and low-quality streams in H.264.
     *
     * ```javascript
     * client.enableDualStream().then(() => {
     *   console.log("Enable Dual stream success!");
     * }).catch(err => {
     *   console.log(err);
     * })
     * ```
     * @category Dual Stream
     */
    enableDualStream(): Promise<void>;
    /**
     * Disables dual-stream mode.
     * @category Dual Stream
     */
    disableDualStream(): Promise<void>;
    /**
     * Sets which video stream of a remote user to subscribe to.
     *
     * If a remote user enables dual-stream mode, the user sends a hybrid of a high-quality video stream and a low-quality video stream. Use this method to set which video stream to subscribe to. The local client subscribes to the high-quality video stream by default.
     *
     * > This method works only if the remote user has enabled dual-stream mode ({@link enableDualStream}).
     * @param uid The ID of the remote user.
     * @param streamType The remote video stream type:
     * - '1': High-bitrate, high-resolution video stream.
     * - '2': Low-bitrate, low-resolution video stream.
     * - 'auto': determined by the server
     * @category Dual Stream
     */
    setRemoteVideoStreamType(uid: UID, streamType: RemoteStreamType): Promise<void>;
    /**
     * Sets the video type of all the remote stream.
     *
     * If a remote user enables dual-stream mode, after using this method, local client will subscribe the specified streamType by default. The local client subscribes to the high-quality video stream by default.
     *
     * > - Leia suggests calling `setRemoteDefaultVideoStreamType` before joining the channel.
     * > - The method call of {@link setRemoteVideoStreamType} to set the video stream type of a specified remote user overrides this method.
     *
     * @param streamType The remote video stream type:
     * - '1': High-bitrate, high-resolution video stream.
     * - '2': Low-bitrate, low-resolution video stream.
     * - 'auto': determined by the server
     * @category Dual Stream
     */
    setRemoteDefaultVideoStreamType(streamType: RemoteStreamType): Promise<void>;
}
export interface SubscribeOptions {
    needSEI: boolean;
}
export interface EventName {
    USER_JOINED: 'user-joined';
    USER_LEFT: 'user-left';
    USER_PUBLISHED: 'user-published';
    USER_UNPUBLISHED: 'user-unpublished';
    TRACK_ENDED: 'track-ended';
    VOLUME_INDICATOR: 'volume-indicator';
    NETWORK_QUALITY: 'network-quality';
    CONNECTION_STATE_CHANGE: 'connection-state-change';
    DUAL_STREAM_CHANGE: 'dual-stream-change';
    USER_VIDEO_SEI: 'user-video-sei';
}
export declare const EventNameMap: EventName;
export declare type UserHandler = (user: ILeiaRTCRemoteUser) => void;
export declare type UserPublishHandler = (user: ILeiaRTCRemoteUser, mediaType: 'audio' | 'video') => void;
export declare type DualStreamChangeHandler = (uid: UID, enabled: boolean) => void;
export declare type UserVideoSEIHandler = (sei: SEIInformation) => void;
/**
 * Reports all the speaking remote users and their volumes.
 *
 * It is disabled by default. You can enable this callback by calling {@link enableAudioVolumeIndicator}.
 * If enabled, it reports the users' volumes every two seconds regardless of whether there are users speaking.
 *
 * The volume is an integer ranging from 0 to 100. Usually a user with volume above five is a speaking user.
 *
 * ``` javascript
 * client.on("volume-indicator", function(result){
 *     result.forEach(function(volume, index){
 *     console.log(`${index} UID ${volume.uid} Level ${volume.level}`);
 *   });
 * });
 * ```
 * @asMemberOf ILeiaRTCClient
 * @event
 */
export declare type VolumeIndicatorHandler = (result: {
    /**
     * The volume of the speaking user, ranging from 0 to 100.
     */
    level: number;
    /**
     * The ID of the speaking user.
     */
    uid: UID;
}[]) => void;
/**
 * Reports the network quality of the local user.
 *
 * After the local user joins the channel, the SDK triggers this callback to report the uplink and downlink network conditions of the local user once every two second.
 *
 * > Leia recommends listening for this event and displaying the network quality.
 *
 * @param stats The network quality of the local user.
 * @asMemberOf ILeiaRTCClient
 * @event
 */
export declare type NetworkQualityHandler = (stats: NetworkQuality) => void;
/**
 * The last-mile network quality.
 *
 * Last mile refers to the connection between the local device and Leia edge server.
 *
 * - After the local user joins the channel, the SDK triggers the [LeiaRTCClient.on("network-quality")]{@link ILeiaRTCClient.event_network_quality} callback once every two seconds and provides the uplink and downlink last-mile network conditions of the user through this interface.
 * - You can call [LeiaRTCClient.getRemoteNetworkQuality]{@link ILeiaRTCClient.getRemoteNetworkQuality} to get the network quality of all remote users to whom the local user subscribes.
 */
export interface NetworkQuality {
    /**
     * The uplink network quality.
     *
     * It is calculated based on the uplink transmission bitrate, uplink packet loss rate, RTT (round-trip time) and jitter.
     *
     * - 0: The quality is unknown.
     * - 1: The quality is excellent.
     * - 2: The quality is good, but the bitrate is less than optimal.
     * - 3: Users experience slightly impaired communication.
     * - 4: Users can communicate with each other, but not very smoothly.
     * - 5: The quality is so poor that users can barely communicate.
     * - 6: The network is disconnected and users cannot communicate.
     */
    uplinkNetworkQuality: 0 | 1 | 2 | 3 | 4 | 5 | 6;
    /**
     * The downlink network quality.
     *
     * It is calculated based on the uplink transmission bitrate, uplink packet loss rate, RTT (round-trip time) and jitter.
     *
     * - 0: The quality is unknown.
     * - 1: The quality is excellent.
     * - 2: The quality is good, but the bitrate is less than optimal.
     * - 3: Users experience slightly impaired communication.
     * - 4: Users can communicate with each other, but not very smoothly.
     * - 5: The quality is so poor that users can barely communicate.
     * - 6: The network is disconnected and users cannot communicate.
     */
    downlinkNetworkQuality: 0 | 1 | 2 | 3 | 4 | 5 | 6;
}
/**
 * Occurs when the state of the connection between the SDK and the server changes.
 * @param curState The current connection state.
 * @param revState The previous connection state.
 * @param reason The reason of disconnection if `curState` is `"DISCONNECTED"`.
 * @asMemberOf IAgoraRTCClient
 * @event
 */
export declare type ConnectionStateChangeHandler = (curState: ConnectionState, revState: ConnectionState, reason?: ConnectionDisconnectedReason) => void;
/**
 * Reason for the disconnection.
 */
export declare enum ConnectionDisconnectedReason {
    /**
     * The user has left the channel.
     */
    LEAVE = "LEAVE",
    /**
     * The network is down, and cannot recover after retry.
     */
    NETWORK_ERROR = "NETWORK_ERROR",
    /**
     * The server returns an error. This is usually caused by incorrect parameter settings.
     */
    SERVER_ERROR = "SERVER_ERROR",
    /**
     * The user is banned.
     */
    UID_BANNED = "UID_BANNED",
    /**
     * The IP is banned.
     */
    IP_BANNED = "IP_BANNED",
    /**
     * The channel is banned.
     */
    CHANNEL_BANNED = "CHANNEL_BANNED",
    FALLBACK = "FALLBACK"
}
export interface ClientEvent {
    [EventNameMap.USER_JOINED]: UserHandler;
    [EventNameMap.USER_LEFT]: UserHandler;
    [EventNameMap.USER_PUBLISHED]: UserPublishHandler;
    [EventNameMap.USER_UNPUBLISHED]: UserPublishHandler;
    [EventNameMap.VOLUME_INDICATOR]: VolumeIndicatorHandler;
    [EventNameMap.NETWORK_QUALITY]: NetworkQualityHandler;
    [EventNameMap.CONNECTION_STATE_CHANGE]: ConnectionStateChangeHandler;
    [EventNameMap.DUAL_STREAM_CHANGE]: DualStreamChangeHandler;
    [EventNameMap.USER_VIDEO_SEI]: UserVideoSEIHandler;
}
export interface LocalTrackEvent {
    [EventNameMap.TRACK_ENDED]: VoidFunction;
}
export interface SocketQueries {
    tokenId: string;
    signature: string;
    sdk: string;
}
interface ConnectUserStream {
    streamId: number;
    label: string;
    audio: boolean;
    video: boolean;
    attributes: StreamAttributes;
}
export interface ConnectUser {
    uid: number;
    clientId: string;
    username: string;
    streams: ConnectUserStream[];
}
export interface ConnectResp {
    errCode: number;
    errMsg: string;
    roomId: string;
    clientId: string;
    users: ConnectUser[];
    iceServers: IceServer[];
    singlePC: boolean;
    p2p: boolean;
    defaultVideoBW: number;
    maxVideoBW: number;
    forceIceRelayMode: boolean;
}
export interface IceServer {
    url: string;
    username: string;
    credential: string;
}
export interface PublishResp {
    errCode: number;
    errMsg: string;
    connectionId: string;
    erizoId: string;
    streamId: number;
}
export interface UnPublishResp {
    errCode: number;
    errMsg: string;
    connectionId: string;
    streamId: number;
}
export interface SubscribeResp {
    errCode: number;
    errMsg: string;
    connectionId: string;
    erizoId: string;
    streamId: number;
    clientOfferSdp: boolean;
}
export interface UnSubscribeResp {
    errCode: number;
    errMsg: string;
    connectionId: string;
    streamId: number;
}
export interface UserJoinLeaveNotice {
    errCode: number;
    errMsg: string;
    userInfo: {
        uid: number;
        username: string;
        clientId: string;
    };
}
export interface ServerConnectionMessage {
    connectionId: string;
    evt: {
        type: string;
        sdp: string;
        candidate: {
            candidate: string;
            sdpMLineIndex: number;
            sdpMid: string;
        };
        negotiated: {
            errCode: number;
            errMsg: string;
        };
        info: {
            level: number;
        };
        config: {
            maxVideoBW: number;
        };
    };
}
export interface ServerMediaSetsMessage {
    connectionId: string;
    erizoId: string;
    streamId: number;
    type: string;
    config: {
        muteVideo: boolean;
        muteAudio: boolean;
        minVideoBW: number;
        maxVideoBW: number;
    };
    errCode: number;
    errMsg: string;
}
export interface StreamAttributes {
    muteVideo: boolean;
    muteAudio: boolean;
    maxVideoBW: number;
    minVideoBW: number;
    simulcastEnable?: boolean;
    simulcastInfos?: SimulcastInfo[];
}
export interface SimulcastInfo {
    simulcastId: number;
    width?: number;
    height?: number;
    framerate?: number;
}
export interface AddStreamNotice {
    video: boolean;
    audio: boolean;
    data: boolean;
    screen: boolean;
    label: string;
    streamId: number;
    connectionId: string;
    userInfo: {
        uid: number;
        username: string;
    };
    attributes: StreamAttributes;
}
export interface RemoveStreamNotice {
    streamId: number;
}
export interface UpdateStreamAttributesNotice {
    streamId: number;
    attributes: StreamAttributes;
}
export interface Connection {
    connectionId: string;
    erizoId: string;
    streamId: number;
    peerConnection: RTCPeerConnection;
}
export interface UserStream {
    label: string;
    streamId: number;
    isSubscribing?: boolean;
    subscribePromise?: Promise<void>;
    dualStreamEnabled?: boolean;
}
export interface DualStreamOptions {
    enabled: boolean;
    templateEnabled: boolean;
    lowStreamParams: LowStreamParameter;
    remoteDefaultVideoStreamType: RemoteStreamType;
    remoteUserVideoStreamTypeMap: Map<number, RemoteStreamType>;
}
export interface AudioTrackNode {
    context: AudioContext;
    source: MediaStreamAudioSourceNode;
    destination: MediaStreamAudioDestinationNode;
    gainNode: GainNode;
    checkVolumeProcessor: ScriptProcessorNode;
    volumeLevel: number;
}
export interface OutdatedRTCRtpReceiver extends RTCRtpReceiver {
    createEncodedStreams: () => {
        readable: ReadableStream;
        writable: WritableStream;
    };
}
export interface EncodedStreamsToWorker {
    uid: UID;
    operation: string;
    readableStream: ReadableStream;
    writableStream: WritableStream;
}
export interface SEIInformation {
    uid: UID;
    payloadType: number;
    payloadSize: number;
    payloadContent: ArrayBuffer;
}
export {};
